@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2021 Arm Limited.
+ * Copyright (c) 2021-2023, 2025 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,12 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_OPERATOR_LIST_H
-#define ARM_COMPUTE_OPERATOR_LIST_H
+#ifndef ACL_ARM_COMPUTE_RUNTIME_OPERATORLIST_H
+#define ACL_ARM_COMPUTE_RUNTIME_OPERATORLIST_H
+
+/** @file
+ * @publicapi
+ */
 
 /** ActivationLayer
  *
@@ -40,6 +44,16 @@
  *
  */
 
+/** AddMulAdd
+ *
+ * Description:
+ * Performs a fused Add + Mul + Add [+ Relu-based-Activation] operation.
+ *
+ * Equivalent Android NNAPI Op:
+ * n/a
+ *
+ */
+
 /** ArgMinMaxLayer
  *
  * Description:
@@ -647,6 +661,16 @@
  *
  */
 
+/** MatMul
+ *
+ * Description:
+ * Computes a matrix multiplication in batches.
+ *
+ * Equivalent Android NNAPI Op:
+ * ANEURALNETWORKS_BATCH_MATMUL
+ *
+ */
+
 /** MaxUnpoolingLayer
  *
  * Description:
@@ -677,6 +701,16 @@
  *
  */
 
+/** NormalizePlanarYUVLayer
+ *
+ * Description:
+ * Function to compute normalization planar YUV layer.
+ *
+ * Equivalent Android NNAPI Op:
+ * n/a
+ *
+ */
+
 /** PadLayer
  *
  * Description:
@@ -720,6 +754,16 @@
  *
  */
 
+/** Pooling3dLayer
+ *
+ * Description:
+ * Function to perform pooling 3D with the specified pooling operation.
+ *
+ * Equivalent Android NNAPI Op:
+ * N/A
+ *
+ */
+
 /** PReluLayer
  *
  * Description:
@@ -804,6 +848,16 @@
  *
  */
 
+/** ReorderLayer
+ *
+ * Description:
+ * Reorders a tensor to a different weights format.
+ *
+ * Equivalent Android NNAPI Op:
+ * n/a
+ *
+ */
+
 /** ReorgLayer
  *
  * Description:
@@ -878,6 +932,16 @@
  *
  */
 
+/** Scatter
+ *
+ * Description:
+ * Function to perform the Scatter operation.
+ *
+ * Equivalent Android NNAPI Op:
+ * n/a
+ *
+ */
+
 /** Select
  *
  * Description:
@@ -999,4 +1063,4 @@
  *
  */
 
-#endif /* ARM_COMPUTE_OPERATOR_LIST_H */
\ No newline at end of file
+#endif // ACL_ARM_COMPUTE_RUNTIME_OPERATORLIST_H
